@@ -1,4 +1,4 @@
-# $Id: bos_plugin.rb,v 1.6 2005/02/23 00:44:45 nisi Exp $
+# $Id: bos_plugin.rb,v 1.7 2005/04/15 23:02:43 nisi Exp $
 
 class BosPlugin
 
@@ -27,8 +27,8 @@ class BosPlugin
 	def get_plugin_item(plugin_file)
 		ret  = {}
 		begin
+			ret[:name] = File::basename(plugin_file,'.rb')
 			open(plugin_file){|f|
-				ret[:name] = f
 				ret[:description] = ""
 				@plist.keys.each{|il| ret[il.intern] = [] }
 				cr = ""
